@@ -3,7 +3,7 @@
  * AUTHORS
  *       Sven Herzberg        <herzi@gnome-de.org>
  *
- * Copyright (C) 2004 Sven Herzberg
+ * Copyright (C) 2004,2005 Sven Herzberg
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,17 +21,22 @@
  * USA
  */
 
-#include <cdebug.h>
+#define CDEBUG_TYPE -1
+#include <cdebug/cdebug.h>
 
 gint
 main(gint argc, gchar** argv) {
+	GObject* object = NULL;
+	
 	g_type_init();
 
-	cdebug("Foo::barMsg()", "this is a simple test");
-
-	cdebugc(G_OBJECT_GET_CLASS(g_object_new(G_TYPE_OBJECT, NULL)), "demo()", "just a demo to demonstrate cdebugc");
-	cdebugo(g_object_new(G_TYPE_OBJECT, NULL), "demo()", "just a demo to demonstrate cdebugo");
+	object = g_object_new(G_TYPE_OBJECT, NULL);
+	cdebug("demo()", "just a demo to demonstrate cdebug without CDEBUG_TYPE");
+	cdebugc(G_OBJECT_GET_CLASS(object), "demo()", "just a demo to demonstrate cdebugc");
+	cdebugo(object, "demo()", "just a demo to demonstrate cdebugo");
 	cdebugt(G_TYPE_OBJECT, "demo()", "just a demo to demonstrate cdebugt");
+	g_object_unref(object);
+	object = NULL;
 	
 	return 0;
 }
