@@ -1,7 +1,7 @@
 #include "gnome-office-helpers.h"
 
 gboolean
-go_rect_equals(const GoRect* rect1, const GoRect* rect2) {
+go_rect_equals(const GORect* rect1, const GORect* rect2) {
 	if(!rect1 || !rect2) {
 		return FALSE;
 	}
@@ -20,12 +20,12 @@ go_rect_equals(const GoRect* rect1, const GoRect* rect2) {
 	}
 }
 
-static GoRect*
-go_rect_copy(GoRect* rect) {
-	GoRect* retval = NULL;
+static GORect*
+go_rect_copy(GORect* rect) {
+	GORect* retval = NULL;
 	g_return_val_if_fail(rect, retval);
 	
-	retval = g_new0(GoRect, 1);
+	retval = g_new0(GORect, 1);
 	*retval = *rect;
 	return retval;
 }
@@ -35,7 +35,7 @@ go_rect_get_type(void) {
 	static GType type = 0;
 
 	if(!type) {
-		type = g_boxed_type_register_static("GoRect", (GBoxedCopyFunc)go_rect_copy, g_free);
+		type = g_boxed_type_register_static("GORect", (GBoxedCopyFunc)go_rect_copy, g_free);
 	}
 	
 	return type;
