@@ -7,7 +7,7 @@
 G_BEGIN_DECLS
 
 #define GO_TYPE_RECT (go_rect_get_type())
-gboolean go_rect_equals(const GoRect* rect1, const GoRect* rect2);
+gboolean go_rect_equals(const GORect* rect1, const GORect* rect2);
 GType    go_rect_get_type(void);
 
 G_END_DECLS
