@@ -29,11 +29,13 @@
 
 G_BEGIN_DECLS
 
-#define G_SOURCE_FUNC(func)	((GSourceFunc)(func))
+#define G_FUNC(func)	    ((GFunc)(func))
+#define G_SOURCE_FUNC(func) ((GSourceFunc)(func))
 
 void gtk_widget_hide_now(GtkWidget* self);
 void gtk_main_flush     (void);
 
+void   gtk_widget_set_cursor  (GtkWidget* self, GdkCursorType type);
 gchar* gtk_window_get_geometry(GtkWindow* self);
 
 G_END_DECLS
