@@ -37,15 +37,16 @@
 #include <gnome.h>
 #include <glade/glade.h>
 
-#include <cdebug.h>
+#define CDEBUG_TYPE cria_application_get_type
+#include <cdebug/cdebug.h>
 #include <helpers/gtk-helpers.h>
 
+#include <widgets/cria-main-window.h>
+#include <widgets/cria-slide-show.h>
 #include <utils/cria-lepton.h>
 
 #include "application.h"
 #include "libglade-support.h"
-#include "main-window.h"
-#include "slide-show.h"
 
 enum {
 	PROP_0,
@@ -136,7 +137,8 @@ criawips_init(int *argc, char ***argv) {
 	GValue		* value;
 	poptContext	  popt_context;
 
-	g_set_prgname (PACKAGE);
+	g_set_prgname(PACKAGE);
+	g_type_init();
 	cdebug("criawips_init()", "start");
 
 	/* initialize i18n */
@@ -264,6 +266,7 @@ criawips_init(int *argc, char ***argv) {
 void
 criawips_shutdown(void) {
 	cria_lepton_shutdown_debug();
+	cdebug_shutdown();
 }
 
 /**
@@ -516,6 +519,16 @@ cria_application_get_sidebar_width(void) {
 	return gconf_client_get_int(self->priv->gconf_client, "/apps/criawips/ui/sidebar_width", NULL);
 }
 
+gboolean
+cria_application_get_templates_visible(void) {
+	return gconf_client_get_bool(self->priv->gconf_client, "/apps/criawips/ui/templates_visible", NULL);
+}
+
+gint
+cria_application_get_templates_width(void) {
+	return gconf_client_get_int(self->priv->gconf_client, "/apps/criawips/ui/templates_width", NULL);
+}
+
 const gchar*
 cria_application_get_zoom(void) {
 	return gconf_client_get_string(self->priv->gconf_client, "/apps/criawips/ui/default_zoom", NULL);
@@ -742,6 +755,16 @@ cria_application_set_sidebar_width(gint sidebar_width) {
 	gconf_client_set_int(self->priv->gconf_client, "/apps/criawips/ui/sidebar_width", sidebar_width, NULL);
 }
 
+void
+cria_application_set_templates_visible(gboolean templates_visible) {
+	gconf_client_set_bool(self->priv->gconf_client, "/apps/criawips/ui/templates_visible", templates_visible, NULL);
+}
+
+void
+cria_application_set_templates_width(gint templates_width) {
+	gconf_client_set_int(self->priv->gconf_client, "/apps/criawips/ui/templates_width", templates_width, NULL);
+}
+
 void
 cria_application_set_zoom(const gchar* zoom) {
 	gconf_client_set_string(self->priv->gconf_client, "/apps/criawips/ui/default_zoom", zoom, NULL);
