@@ -3,7 +3,7 @@
 
 #include <glib-object.h>
 
-#include <layout-block.h>
+#include "block.h"
 
 G_BEGIN_DECLS
 
