@@ -8,6 +8,11 @@
 
 G_BEGIN_DECLS
 
+/* enumerations from "cria-alignment.h" */
+GType cria_alignment_get_type (void);
+#define CRIA_TYPE_ALIGNMENT (cria_alignment_get_type())
+GType cria_valignment_get_type (void);
+#define CRIA_TYPE_VALIGNMENT (cria_valignment_get_type())
 /* enumerations from "cria-format.h" */
 GType cria_format_domain_get_type (void);
 #define CRIA_TYPE_FORMAT_DOMAIN (cria_format_domain_get_type())
