@@ -203,7 +203,7 @@ cria_presentation_get_property(GObject* object, guint prop_id, GValue* value, GP
  *
  * Returns the size of a slide
  */
-const GoPoint*
+const GOPoint*
 cria_presentation_get_slide_size(CriaPresentation* self) {
 	g_return_val_if_fail(CRIA_IS_PRESENTATION(self), NULL);
 	
@@ -499,23 +499,18 @@ cria_presentation_set_title(CriaPresentation* self, const gchar* title) {
 
 void
 cria_presentation_set_uri(CriaPresentation* self, GnomeVFSURI* uri) {
-	GnomeVFSURI* old;
-	
 	g_return_if_fail(CRIA_IS_PRESENTATION(self));
 	/* unfortunately we don't have GType information for GnomeVFSURI */
 	/* g_return_if_fail(self->uri == NULL || GNOME_IS_VFS_URI(self->uri)); */
 	/* g_return_if_fail(uri == NULL || GNOME_IS_VFS_URI(uri)); */
 
-	old = self->uri;
-
 	if(self->uri) {
 		gnome_vfs_uri_unref(self->uri);
 		self->uri = NULL;
 	}
 
-	self->uri = uri;
 	if(uri) {
-		gnome_vfs_uri_ref(uri);
+		self->uri = gnome_vfs_uri_ref(uri);
 	}
 
 	g_object_notify(G_OBJECT(self), "uri");
