@@ -32,7 +32,7 @@ struct _CriaSlide {
 	GObject		  base_instance;
 	gchar		* title;
 
-	GHashTable	* blocks;
+	GList		* elements;
 	CriaSlide	* master_slide;
 	CriaTheme	* theme;
 	gchar		* comment;
@@ -43,6 +43,10 @@ struct _CriaSlide {
 
 struct _CriaSlideClass {
 	GObjectClass	  base_class;
+
+	/* signals */
+	void (*element_added) (CriaSlide* self,
+			       CriaSlideElement* element);
 };
 
 G_END_DECLS
