@@ -290,13 +290,13 @@ cria_slide_get_property(GObject* object, guint prop_id, GValue* value, GParamSpe
  *
  * ...
  *
- * Returns a #GoPoint defining the size of the slide in master coordinates
+ * Returns a #GOPoint defining the size of the slide in master coordinates
  * (576dpi). Don't forget to g_free it.
  */
-GoPoint*
+GOPoint*
 cria_slide_get_size(CriaSlide* self) {
 #warning "Slide::getSize(): FIXME return value from presentation"
-	GoPoint* size = g_new0(GoPoint,1);
+	GOPoint* size = g_new0(GOPoint,1);
 	size->x = 5760;
 	size->y = 4320;
 	return size;
