@@ -64,10 +64,10 @@ CriaBackground*	cria_slide_get_background      (CriaSlide	* self,
 CriaSlideElement*cria_slide_get_element        (CriaSlide	* self,
 						guint             index);
 GList*          cria_slide_get_elements        (CriaSlide       * self);
-GoPoint*	cria_slide_get_display_size    (CriaSlide	* self,
+GOPoint*	cria_slide_get_display_size    (CriaSlide	* self,
 						GdkScreen	* screen);
 CriaSlide*	cria_slide_get_master_slide    (CriaSlide const	* self);
-GoPoint*	cria_slide_get_size	       (CriaSlide	* self);
+GOPoint*	cria_slide_get_size	       (CriaSlide	* self);
 CriaTheme*	cria_slide_get_theme	       (CriaSlide	* self);
 const gchar*	cria_slide_get_title	       (CriaSlide	* self);
 CriaSlide*	cria_slide_new		       (CriaSlideList* container);
