@@ -221,7 +221,7 @@ cria_sax_0_0_1_element_block_start(GHashTable* hash_table, Sax001Data* data) {
 	CriaBlock	* block;
 	const gchar	* attr1,
 	      		* attr2;
-	const GoPoint 	* slide_size;
+	const GOPoint 	* slide_size;
 	
 	g_return_if_fail(CRIA_IS_SLIDE(g_list_last(data->tags)->data));
 	g_return_if_fail(CRIA_IS_PRESENTATION(data->tags->data));
@@ -234,7 +234,7 @@ cria_sax_0_0_1_element_block_start(GHashTable* hash_table, Sax001Data* data) {
 	attr1 = g_hash_table_lookup(hash_table, "x");
 	attr2 = g_hash_table_lookup(hash_table, "width");
 	if((attr1 != NULL && strlen(attr1)) || (attr2 != NULL && strlen(attr2))) {
-		go_unit_t	x = 0.0 + cria_unit_to_pixels(attr1, slide_size->x / MASTER_COORDINATES_PER_POINT) * MASTER_COORDINATES_PER_POINT,
+		GODistance	x = 0.0 + cria_unit_to_pixels(attr1, slide_size->x / MASTER_COORDINATES_PER_POINT) * MASTER_COORDINATES_PER_POINT,
 				w = 0.0 + cria_unit_to_pixels(attr2, slide_size->x / MASTER_COORDINATES_PER_POINT) * MASTER_COORDINATES_PER_POINT;
 		
 		g_object_set(G_OBJECT(block),
@@ -246,7 +246,7 @@ cria_sax_0_0_1_element_block_start(GHashTable* hash_table, Sax001Data* data) {
 	attr1 = g_hash_table_lookup(hash_table, "y");
 	attr2 = g_hash_table_lookup(hash_table, "height");
 	if((attr1 != NULL && strlen(attr1)) || (attr2 != NULL && strlen(attr2))) {
-		go_unit_t	y = 0.0 + cria_unit_to_pixels(attr1, slide_size->y / MASTER_COORDINATES_PER_POINT) * MASTER_COORDINATES_PER_POINT,
+		GODistance	y = 0.0 + cria_unit_to_pixels(attr1, slide_size->y / MASTER_COORDINATES_PER_POINT) * MASTER_COORDINATES_PER_POINT,
 				h = 0.0 + cria_unit_to_pixels(attr2, slide_size->y / MASTER_COORDINATES_PER_POINT) * MASTER_COORDINATES_PER_POINT;
 		
 		g_object_set(G_OBJECT(block),
@@ -309,8 +309,7 @@ cria_sax_0_0_1_element_block_end(Sax001Data* data) {
 			 CRIA_IS_SLIDE(g_list_nth(data->tags, g_list_length(data->tags) - 2)->data));
 
 	if(data->cdata) {
-		cria_block_set_text(CRIA_BLOCK(g_list_last(data->tags)->data),
-				    data->cdata->str);
+		cria_text_model_append(cria_block_get_model(CRIA_BLOCK(g_list_last(data->tags)->data)), data->cdata->str);
 		g_string_free(data->cdata, TRUE);
 		data->cdata = NULL;
 	}
