@@ -28,6 +28,7 @@
 #include <rendering/cria-block-renderer-priv.h>
 
 #include <inttypes.h>
+#include <string.h>
 #include <glib/gi18n.h>
 #include <libgnomecanvas/libgnomecanvas.h>
 
@@ -40,7 +41,7 @@
 #include <utils/cria-units.h>
 #include <dom/cria-format.h>
 #include <dom/cria-block-view.h>
-#include <rendering/cria-canvas-text.h>
+#include <rendering/cria-canvas-text-view.h>
 #include <rendering/cria-format.h>
 #include <rendering/cria-slide-renderer.h>
 
@@ -156,26 +157,16 @@ cbr_reset_caret(CriaBlockRenderer* self) {
 
 static void cbr_update_position(CriaBlockRenderer* self);
 
-static void
-cbr_notify_text(CriaBlockRenderer* self, GParamSpec* pspec, CriaCanvasText* cct) {
-	gchar const* text;
-	g_object_get(cct, "text", &text, NULL);
-	if(text && strcmp(text, MSG_CLICK_HERE)) {
-		cria_block_set_text(cria_block_renderer_get_block(self), text);
-	}
-	cbr_update_position(self);
-}
-
 static void
 cbr_ensure_text_item(CriaBlockRenderer* self) {
 	if(!self->text_item) {
 		self->text_item = gnome_canvas_item_new(GNOME_CANVAS_GROUP(self),
-							CRIA_TYPE_CANVAS_TEXT,
+							CRIA_TYPE_CANVAS_TEXT_VIEW,
 							"clip", TRUE,
 							"size-set", TRUE,
 							NULL);
 		g_signal_connect_swapped(self->text_item, "notify::text",
-					 G_CALLBACK(cbr_notify_text), self);
+					 G_CALLBACK(cbr_update_position), self);
 		g_signal_connect_swapped(self->text_item, "notify::cursor",
 					 G_CALLBACK(cbr_update_cursor_position), self);
 	}
@@ -339,8 +330,8 @@ GET_RECURSIVE_FROM_BLOCK_FUNC(CriaLepton, format, 0);
  * Returns the position of the rendered block (even if it's specified in one of
  * its templates).
  */
-static GoRect const default_rect = {0l, 0l, 0l, 0l};
-GET_RECURSIVE_FROM_BLOCK_FUNC_PTR(GoRect, position, default_rect);
+static GORect const default_rect = {0l, 0l, 0l, 0l};
+GET_RECURSIVE_FROM_BLOCK_FUNC_PTR(GORect, position, default_rect);
 
 static void
 cbr_update_cursor_position(CriaBlockRenderer* self) {
@@ -555,7 +546,7 @@ get_justification_from_alignment(CriaAlignment align) {
 }
 
 static gdouble
-get_x_from_alignment(CriaAlignment align, go_unit_t left, go_unit_t right) {
+get_x_from_alignment(CriaAlignment align, GODistance left, GODistance right) {
 	switch(align) {
 	case CRIA_ALIGNMENT_RIGHT:
 		return 1.0 * right;
@@ -572,7 +563,7 @@ get_x_from_alignment(CriaAlignment align, go_unit_t left, go_unit_t right) {
 }
 
 static gdouble
-get_y_from_valignment(CriaVAlignment align, go_unit_t top, go_unit_t bottom) {
+get_y_from_valignment(CriaVAlignment align, GODistance top, GODistance bottom) {
 	switch(align) {
 	case CRIA_ALIGNMENT_BOTTOM:
 		return 1.0 * bottom;
@@ -589,7 +580,7 @@ get_y_from_valignment(CriaVAlignment align, go_unit_t top, go_unit_t bottom) {
 
 static gboolean
 cbr_displays_text(CriaBlockRenderer const* self) {
-	gchar const* text = cria_block_get_markup(cria_block_renderer_get_block(self));
+	gchar const* text = cria_text_model_get_text(cria_block_get_model(cria_block_renderer_get_block(self)));
 	gboolean retval = /* non-interactive items display what they're set to: */
 			  !CRIA_ITEM_IS_INTERACTIVE(self) ||
 			  /* focused items display their real text: */
@@ -613,7 +604,7 @@ cbr_displays_text(CriaBlockRenderer const* self) {
 static void
 cbr_update_position(CriaBlockRenderer* self) {
 #warning "updatePosition(): FIXME: make this a callback for the 'notify::position' signal of the block"
-	GoRect block_position = cbr_get_position(self);
+	GORect block_position = cbr_get_position(self);
 	gdouble x, y;
 	CriaAlignment  align  = CRIA_ALIGNMENT_CENTER;
 	CriaVAlignment valign = CRIA_ALIGNMENT_MIDDLE;
@@ -764,7 +755,7 @@ render_block_content(CriaBlockRenderer* self) {
 		     "anchor", anchor,
 		     "fill-color-rgba", cbr_get_color(self),
 		     "justification", justification,
-		     "text", cria_block_get_markup(block),
+		     "text", cria_text_model_get_text(cria_block_get_model(block)),
 		     NULL);
 #endif
 
@@ -852,6 +843,7 @@ cria_block_renderer_set_block(CriaBlockRenderer* self, CriaBlock* block) {
 	}
 
 	if(self->block != NULL) {
+		g_object_set(self->text_item, "model", NULL, NULL);
 		g_signal_handlers_disconnect_by_func(self->block, cbr_update_font, self);
 		g_object_unref(self->block);
 		self->block = NULL;
@@ -861,7 +853,9 @@ cria_block_renderer_set_block(CriaBlockRenderer* self, CriaBlock* block) {
 
 	g_signal_connect_swapped(self->block, "format-changed",
 			         G_CALLBACK(cbr_format_changed), self);
-	
+
+	cbr_ensure_text_item(self);
+	g_object_set(self->text_item, "model", cria_block_get_model(block), NULL);
 	render_block(self);
 #ifndef WITH_CCC
 	if(cria_item_is_interactive(CRIA_ITEM(self)) &&
