@@ -41,6 +41,18 @@ struct _CriaCanvasText {
 	GtkIMContext   * im_context;
 };
 
+struct _CriaCanvasTextClass {
+	GnomeCanvasTextClass text_class;
+
+	/* vtable */
+	void (*delete) (CriaCanvasText* self,
+			guint           offset,
+			gsize           length);
+	void (*insert) (CriaCanvasText* self,
+			gchar const   * text,
+			gsize           offset);
+};
+
 G_END_DECLS
 
 #endif /* !CRIAWIPS_CANVAS_TEXT_PRIVATE_H */
