@@ -70,16 +70,38 @@ cct_move_cursor(CriaCanvasText* self, gint direction) {
 }
 
 static void
-cct_commit_cb(CriaCanvasText* self, gchar* arg1, GtkIMContext* im_context) {
+cct_insert(CriaCanvasText* self, gchar const* text, gsize position) {
 	GString* str = g_string_new(pango_layout_get_text(GNOME_CANVAS_TEXT(self)->layout));
-	g_string_insert(str, self->cursor + self->cursor_trail, arg1);
-
+	g_string_insert(str, position, text);
 	g_object_set(self, "text", str->str, NULL);
-	cct_move_cursor(self, 1);
-
 	g_string_free(str, TRUE);
 }
 
+static gsize
+g_utf8_length_next(gchar const* utf8) {
+	return g_utf8_find_next_char(utf8, NULL) - utf8;
+}
+
+static void
+cct_insert_and_move_cursor(CriaCanvasText* self, char* text) {
+	if(CRIA_CANVAS_TEXT_GET_CLASS(self)->insert) {
+		gsize i = self->cursor;
+
+		if(self->cursor_trail) {
+			gchar const* old  = pango_layout_get_text(GNOME_CANVAS_TEXT(self)->layout);
+			gchar const* next = g_utf8_find_next_char(old + self->cursor, NULL);
+			i += (next - (old + self->cursor));
+		}
+		
+		CRIA_CANVAS_TEXT_GET_CLASS(self)->insert(self, text, i);
+		
+		/* move the cursor AFTER inserting text */
+		for(i = text ? g_utf8_strlen(text, -1) : 0; i > 0; i--) {
+			cct_move_cursor(self, 1);
+		}
+	}
+}
+
 static void
 cria_canvas_text_init(CriaCanvasText* self) {
 	self->im_context = gtk_im_multicontext_new();
@@ -87,14 +109,14 @@ cria_canvas_text_init(CriaCanvasText* self) {
 	//gtk_im_context_set_client_window(self->im_context, gdk_window_from_the_canvas);
 
 	g_signal_connect_swapped(self->im_context, "commit",
-				 G_CALLBACK(cct_commit_cb), self);
+				 G_CALLBACK(cct_insert_and_move_cursor), self);
 }
 
 static void
 cct_finalize(GObject* object) {
 	CriaCanvasText* self = CRIA_CANVAS_TEXT(object);
 
-	g_signal_handlers_disconnect_by_func(self->im_context, cct_commit_cb, self);
+	g_signal_handlers_disconnect_by_func(self->im_context, cct_insert_and_move_cursor, self);
 	g_object_unref(self->im_context);
 }
 
@@ -148,50 +170,56 @@ cct_event(GnomeCanvasItem* item, GdkEvent* ev) {
 				retval = TRUE;
 				break;
 			case GDK_BackSpace:
-				offset = -1;
+				offset = 1;
 				/* fall through */
 			case GDK_Delete:
-				{
-					GString* str = g_string_new(pango_layout_get_text(GNOME_CANVAS_TEXT(self)->layout));
-					const gchar* cursor = str->str + self->cursor + self->cursor_trail;
+				if(CRIA_CANVAS_TEXT_GET_CLASS(self)->delete) {
+					gchar const* text     = pango_layout_get_text(GNOME_CANVAS_TEXT(self)->layout);
+					gsize        cursor   = self->cursor +
+								self->cursor_trail * g_utf8_length_next(text + self->cursor);
+					gchar const* cursor_p = cursor + text;
 					gsize length_of_deleted_char = 0;
 					
-					if(offset == 0) {
-						length_of_deleted_char = g_utf8_find_next_char(cursor, NULL) - cursor;
+					if(!offset) {
+						length_of_deleted_char = (gsize)g_utf8_find_next_char(cursor_p, NULL);
 					} else {
-						length_of_deleted_char = cursor - g_utf8_find_prev_char(str->str, cursor);
+						length_of_deleted_char = (gsize)g_utf8_find_prev_char(text, cursor_p);
 					}
 
-					/* offset is 0 or -1, so we don't do evil stuff by multiplying */
+					length_of_deleted_char = labs(length_of_deleted_char - (gsize)cursor_p);
+					
+					/* offset is 0 or 1, so we don't do evil stuff by multiplying */
 					offset *= length_of_deleted_char;
-					g_string_erase(str, (cursor - str->str) + offset, length_of_deleted_char);
-					/* the cursor MUST be moved before the new text is set because
-					 * the old cursor position might be invalid in the new text */
-					cct_move_cursor(self, offset);
-					g_object_set(self, "text", str->str, NULL);
-					g_string_free(str, TRUE);
-					retval = TRUE;
+
+					if(cursor >= offset && (cursor + 1 - offset) <= strlen(text)) {
+						/* don't delete characters before or after the string */
+
+						/* the cursor MUST be moved before the new text is set because
+						 * the old cursor position might be invalid in the new text */
+						if(offset) {
+							cct_move_cursor(self, -offset);
+						}
+						
+						cdebug("event()", "calling delete(%p, %li, %li)",
+						       self,
+						       cursor - offset,
+						       length_of_deleted_char);
+						CRIA_CANVAS_TEXT_GET_CLASS(self)->delete(self, cursor - offset, length_of_deleted_char);
+					}
 				}
+				retval = TRUE;
 				break;
 			case GDK_Return:
 			case GDK_KP_Enter:
 				{
-					GString* str = NULL;
-					cdebug("event()", "Entered <line break>");
-					str = g_string_new(pango_layout_get_text(GNOME_CANVAS_TEXT(self)->layout));
-					g_string_insert(str, self->cursor + self->cursor_trail, "\n");
-					g_object_set(self, "text", str->str, NULL);
-					cdebug("event()", "Added <line break> to the text");
-					cct_move_cursor(self, 1);
-					cdebug("event()", "Emitted the 'notify::cursor'-signal for <line break>");
-					g_string_free(str, TRUE);
+					cct_insert_and_move_cursor(self, "\n");
 					retval = TRUE;
 				}
 				break;
 			case GDK_Home:
 			case GDK_KP_Home:
 				{
-					const gchar* text = pango_layout_get_text(GNOME_CANVAS_TEXT(self)->layout);
+					gchar const* text = pango_layout_get_text(GNOME_CANVAS_TEXT(self)->layout);
 					
 					while(self->cursor > 0 && text[self->cursor - 1] != '\n') {
 						cct_move_cursor(self, -1);
@@ -206,7 +234,8 @@ cct_event(GnomeCanvasItem* item, GdkEvent* ev) {
 					const gchar* text = pango_layout_get_text(GNOME_CANVAS_TEXT(self)->layout);
 					guint        len  = text ? strlen(text) : 0;
 					
-					while((guint)(self->cursor + self->cursor_trail) < len && text[(self->cursor + self->cursor_trail)] != '\n') {
+					while((guint)(self->cursor + self->cursor_trail * g_utf8_length_next(text + self->cursor)) < len &&
+					  text[(self->cursor + self->cursor_trail * g_utf8_length_next(text + self->cursor))] != '\n') {
 						cct_move_cursor(self, 1);
 					}
 					retval = TRUE;
@@ -228,6 +257,14 @@ cct_event(GnomeCanvasItem* item, GdkEvent* ev) {
 	return retval;
 }
 
+static void
+cct_delete(CriaCanvasText* self, gsize offset, gsize num_deleted) {
+	GString* str = g_string_new(pango_layout_get_text(GNOME_CANVAS_TEXT(self)->layout));
+	g_string_erase(str, offset, num_deleted);
+	g_object_set(self, "text", str->str, NULL);
+	g_string_free(str, TRUE);
+}
+
 static void
 cria_canvas_text_class_init(CriaCanvasTextClass* self_class) {
 	GObjectClass        * go_class;
@@ -259,5 +296,9 @@ cria_canvas_text_class_init(CriaCanvasTextClass* self_class) {
 	/* GnomeCanvasItemClass */
 	gci_class = GNOME_CANVAS_ITEM_CLASS(self_class);
 	gci_class->event = cct_event;
+
+	/* CriaCanvasTextClass */
+	self_class->delete = cct_delete;
+	self_class->insert = cct_insert;
 }
 
