@@ -101,7 +101,7 @@ csr_render(CcNode* node, cairo_t* cr) {
 #else
 static void
 csr_update_focus_layer_size(CriaSlideRenderer* self) {
-	GoPoint* size;
+	GOPoint* size;
 	g_return_if_fail(GNOME_IS_CANVAS_ITEM(self->focus_layer));
 	g_return_if_fail(CRIA_IS_SLIDE(self->slide));
 	
@@ -285,7 +285,7 @@ cria_slide_renderer_class_init(CriaSlideRendererClass* self_class) {
 #ifndef WITH_CCC
 static void
 csr_update_frame_size(CriaSlideRenderer* self) {
-	GoPoint* size;
+	GOPoint* size;
 	g_return_if_fail(GNOME_IS_CANVAS_ITEM(self->frame));
 	g_return_if_fail(CRIA_IS_SLIDE(self->slide));
 
@@ -317,7 +317,7 @@ csr_ensure_frame(CriaSlideRenderer* self) {
 
 static void
 csr_update_shadow_size(CriaSlideRenderer* self) {
-	GoPoint* size;
+	GOPoint* size;
 	g_return_if_fail(GNOME_IS_CANVAS_ITEM(self->shadow));
 	g_return_if_fail(CRIA_IS_SLIDE(self->slide));
 
@@ -567,7 +567,7 @@ csr_ensure_background_renderer(CriaSlideRenderer* self) {
 
 static void
 update_slide_size(CriaSlideRenderer* self) {
-	GoPoint* size;
+	GOPoint* size;
 #ifdef WITH_CCC
 	CcDRect box;
 #endif
@@ -595,7 +595,7 @@ update_slide_size(CriaSlideRenderer* self) {
 		csr_update_focus_layer_size(self);
 	}
 	if(self->background_renderer) {
-		GoRect rect = {
+		GORect rect = {
 			0, /* top */
 			0, /* left */
 			size->y, /* bottom */
