@@ -29,6 +29,6 @@
 
 #define MASTER_COORDINATES_PER_POINT (576/72)
 
-go_unit_t cria_unit_to_pixels(const gchar* size, go_unit_t size_reference);
+GODistance cria_unit_to_pixels(const gchar* size, GODistance size_reference);
 
 #endif /* !CRIAWIPS_UNITS_H */
