@@ -915,6 +915,7 @@ cria_main_window_save_as(CriaMainWindow* self) {
 			/* got GTK_RESPONSE_ACCEPT */
 			GError     * error = NULL;
 			GnomeVFSURI* uri;
+			GnomeVFSURI* old_uri;
 			gchar      * text_uri;
 			gboolean     write = TRUE;
 	
@@ -923,8 +924,13 @@ cria_main_window_save_as(CriaMainWindow* self) {
 			text_uri = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
 			uri = gnome_vfs_uri_new(text_uri);
 			g_free(text_uri);
+
+			old_uri = cria_presentation_get_uri(cria_main_window_get_presentation(self));
+			if(old_uri) {
+				old_uri = gnome_vfs_uri_ref(old_uri);
+			}
 	
-			if(write && gnome_vfs_uri_exists(uri) && !gnome_vfs_uri_equal(uri, cria_presentation_get_uri(cria_main_window_get_presentation(self)))) {
+			if(write && gnome_vfs_uri_exists(uri) && old_uri && !gnome_vfs_uri_equal(uri, old_uri)) {
 				GtkWidget* qdialog = gtk_message_dialog_new(GTK_WINDOW(self),
 									    GTK_DIALOG_DESTROY_WITH_PARENT,
 									    GTK_MESSAGE_WARNING,
@@ -969,11 +975,17 @@ cria_main_window_save_as(CriaMainWindow* self) {
 				} else {
 					gchar* text_uri = gnome_vfs_uri_to_string(uri, GNOME_VFS_URI_HIDE_PASSWORD);
 					cria_application_add_to_recent(text_uri);
+					cria_presentation_set_uri(cria_main_window_get_presentation(self), uri);
 					g_free(text_uri);
 				}
 
 				done = TRUE;
 			}
+
+			gnome_vfs_uri_unref(uri);
+			if(old_uri) {
+				gnome_vfs_uri_unref(old_uri);
+			}
 		}
 	} while (!done);
 
@@ -1357,7 +1369,7 @@ static void
 cmw_finalize_dnd_action(CriaMainWindow* self) {
 	gtk_statusbar_pop(GTK_STATUSBAR(self->priv->status_bar),
 			  self->priv->status_drag_to_create);
-	gtk_widget_set_cursor(self->priv->slide_editor, GDK_LAST_CURSOR);
+	gtk_widget_set_cursor(self->priv->slide_editor, GDK_LEFT_PTR);
 }
 
 static void
