@@ -26,12 +26,10 @@
 #include <inttypes.h>
 #include <string.h>
 
-#include <glib.h>
-#include <glib-object.h>
 #include <gtk/gtktreednd.h>
 
+#define CDEBUG_TYPE cria_sidebar_model_get_type
 #include <cdebug/cdebug.h>
-#include "presentation-view.h"
 
 enum {
 	PROP_0,
@@ -178,7 +176,7 @@ cria_sidebar_model_get_flags(GtkTreeModel* tree_model) {
 
 static gboolean
 cria_sidebar_model_get_iter(GtkTreeModel* tree_model, GtkTreeIter* iter, GtkTreePath* path) {
-	gint		    i;
+	guint		    i;
 	CriaSidebarModel* self;
 	
 	g_return_val_if_fail(CRIA_IS_SIDEBAR_MODEL(tree_model), FALSE);
@@ -286,7 +284,7 @@ cslp_row_draggable(GtkTreeDragSource* source, GtkTreePath* path) {
 static CriaSlideList*
 cslp_container_for_path_depth(CriaSidebarModel* self, GtkTreePath* path, gint depth) {
 	CriaSlideList* c = CRIA_SLIDE_LIST(self->priv->presentation);
-	guint i = 0;
+	gint i = 0;
 
 	g_return_val_if_fail(gtk_tree_path_get_depth(path)  >= depth, NULL);
 
@@ -495,7 +493,7 @@ cria_sidebar_model_iter_has_child(GtkTreeModel* tree_model, GtkTreeIter* iter) {
 
 static gboolean
 cria_sidebar_model_iter_next(GtkTreeModel* tree_model, GtkTreeIter* iter) {
-	gint             n;
+	guint             n;
 	gboolean         retval = FALSE;
 	CriaPresentation*presentation;
 	CriaSlide       *slide;
