@@ -337,21 +337,21 @@ cria_slide_show_class_init(CriaSlideShowClass* cria_slide_show_class) {
 	cria_slide_set_title(cria_slide_show_class->after_show, _("End of Presentation"));
 	block = cria_block_new("message");
 	/* TRANSLATORS: there is a UTF-8 Character for the ellipsis (...), please use it and not three dots */
-	cria_block_set_text(block, _("Press a Key or click to close this Window..."));
+	cria_text_model_set_text(cria_block_get_model(block), _("Press a Key or click to close this Window..."));
 	cria_block_set_color(block, &gray);
 	cria_block_set_alignment(block, CRIA_ALIGNMENT_CENTER);
 	cria_block_set_valignment(block, CRIA_ALIGNMENT_MIDDLE);
 	{
 		GOColor  color = RGBA_BLACK;
-		GoPoint* size = cria_slide_get_size(cria_slide_show_class->after_show);
+		GOPoint* size = cria_slide_get_size(cria_slide_show_class->after_show);
 
 		cdebugc(cria_slide_show_class, "init()", "Slide size %llix%lli", size->x, size->y);
 #warning "static SlideShow::init(): FIXME: get rid of g_object_set here; use cria_block_set_position"
 		cria_background_set_color(cria_slide_get_background(cria_slide_show_class->after_show, TRUE), &color);
 		g_object_set(G_OBJECT(block),
-			     "left", (go_unit_t)0,
+			     "left", (GODistance)0,
 			     "right", size->x,
-			     "top", (go_unit_t)0,
+			     "top", (GODistance)0,
 			     "bottom", size->y,
 			     NULL);
 	}
@@ -577,7 +577,7 @@ cria_slide_show_prev_page_event(GtkGestureHandler* gh, gpointer user_data_a, gpo
 static void
 cria_slide_show_render(CriaSlideShow* self) {
 	CriaSlide	* slide;
-	GoPoint		* slide_s;
+	GOPoint		* slide_s;
 	gchar		* title;
 	CcRectangle	  rect;
 
